TheCannon
=========

This is the code associated with *The Cannon*, a data-driven method for 
determining stellar labels (physical parameters and chemical abundances) from
stellar spectra in the context of large spectroscopic surveys. It closely 
follows the method outlined in Ness et al. 2015, although some minor changes 
have been made. A description of these changes is outlined in Ho et al. 2016.

Documentation for The Cannon can be found here_. 

.. _here: https://annayqho.github.io/TheCannon/

Authors
-------

* **Anna Ho** (MPIA)
* **Melissa Ness** (MPIA)
* **David W. Hogg** (NYU CCPP)(MPIA)
* **Hans-Walter Rix** (MPIA)

License and Citation
--------------------

Copyright 2015 the authors. TheCannon is open-source software released under 
the MIT License. See the file ``LICENSE`` for details.

A condition on using this code for any academic purpose is citation of
Ness et al. 2015 (arXiv:1501.07604) and Ho et al. 2016 (arXiv:1602.00303). 

Projects
--------

* Survey Cross-Calibration with The Cannon: Apogee-scale Stellar Labels from Lamost Spectra
